@@ -1,6 +1,6 @@
 // main.cpp
 
-// Copyright (C) 2011-2012 by Werner Lemberg.
+// Copyright (C) 2011-2013 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -162,6 +162,7 @@ show_help(bool
 "      --debug                print debugging information\n"
 #endif
 "  -c, --components           hint glyph components separately\n"
+"  -d, --dehint               remove all hints\n"
 "  -f, --latin-fallback       set fallback script to latin\n"
 "  -G, --hinting-limit=N      switch off hinting above this PPEM value\n"
 "                             (default: %d); value 0 means no limit\n"
@@ -293,7 +294,7 @@ show_version()
 #else
 "ttfautohint " VERSION "\n"
 #endif
-"Copyright (C) 2011-2012 Werner Lemberg <wl@gnu.org>.\n"
+"Copyright (C) 2011-2013 Werner Lemberg <wl@gnu.org>.\n"
 "License: FreeType License (FTL) or GNU GPLv2.\n"
 "This is free software: you are free to change and redistribute it.\n"
 "There is NO WARRANTY, to the extent permitted by law.\n");
@@ -331,6 +332,8 @@ main(int argc,
   const char* x_height_snapping_exceptions_string = NULL;
   bool have_x_height_snapping_exceptions_string = false;
 
+  bool dehint = false;
+
 #ifndef BUILD_GUI
   bool debug = false;
 
@@ -368,6 +371,7 @@ main(int argc,
 #ifndef BUILD_GUI
       {"debug", no_argument, NULL, DEBUG_OPTION},
 #endif
+      {"dehint", no_argument, NULL, 'd'},
       {"hinting-limit", required_argument, NULL, 'G'},
       {"hinting-range-max", required_argument, NULL, 'r'},
       {"hinting-range-min", required_argument, NULL, 'l'},
@@ -413,7 +417,7 @@ main(int argc,
     };
 
     int option_index;
-    int c = getopt_long_only(argc, argv, "cfG:hil:npr:stVvw:Wx:X:",
+    int c = getopt_long_only(argc, argv, "cdfG:hil:npr:stVvw:Wx:X:",
                              long_options, &option_index);
     if (c == -1)
       break;
@@ -424,6 +428,10 @@ main(int argc,
       hint_with_components = false;
       break;
 
+    case 'd':
+      dehint = true;
+      break;
+
     case 'f':
       latin_fallback = 1;
       break;
@@ -529,6 +537,16 @@ main(int argc,
     }
   }
 
+  if (dehint)
+  {
+    // -d makes ttfautohint ignore all other hinting options
+    have_hinting_range_min = false;
+    have_hinting_range_max = false;
+    have_hinting_limit = false;
+    have_increase_x_height = false;
+    have_x_height_snapping_exceptions_string = false;
+  }
+
   if (!have_hinting_range_min)
     hinting_range_min = TA_HINTING_RANGE_MIN;
   if (!have_hinting_range_max)
@@ -612,26 +630,6 @@ main(int argc,
   if (num_args > 2)
     show_help(false, true);
 
-  FILE* out;
-  if (num_args > 1)
-  {
-    out = fopen(argv[optind + 1], "wb");
-    if (!out)
-    {
-      fprintf(stderr, "The following error occurred while opening font `%s':\n"
-                      "\n"
-                      "  %s\n",
-                      argv[optind + 1], strerror(errno));
-      exit(EXIT_FAILURE);
-    }
-  }
-  else
-  {
-    if (isatty(fileno(stdout)))
-      show_help(false, true);
-    out = stdout;
-  }
-
   FILE* in;
   if (num_args > 0)
   {
@@ -652,6 +650,32 @@ main(int argc,
     in = stdin;
   }
 
+  FILE* out;
+  if (num_args > 1)
+  {
+    if (!strcmp(argv[optind], argv[optind + 1]))
+    {
+      fprintf(stderr, "Input and output file names must not be identical\n");
+      exit(EXIT_FAILURE);
+    }
+
+    out = fopen(argv[optind + 1], "wb");
+    if (!out)
+    {
+      fprintf(stderr, "The following error occurred while opening font `%s':\n"
+                      "\n"
+                      "  %s\n",
+                      argv[optind + 1], strerror(errno));
+      exit(EXIT_FAILURE);
+    }
+  }
+  else
+  {
+    if (isatty(fileno(stdout)))
+      show_help(false, true);
+    out = stdout;
+  }
+
   const unsigned char* error_string;
   Progress_Data progress_data = {-1, 1, 0};
   Info_Data info_data;
@@ -681,6 +705,8 @@ main(int argc,
     info_data.latin_fallback = latin_fallback;
     info_data.symbol = symbol;
 
+    info_data.dehint = dehint;
+
     int ret = build_version_string(&info_data);
     if (ret == 1)
       fprintf(stderr, "Warning: Can't allocate memory"
@@ -707,7 +733,7 @@ main(int argc,
                  "pre-hinting, hint-with-components,"
                  "increase-x-height, x-height-snapping-exceptions,"
                  "fallback-script, symbol,"
-                 "debug",
+                 "dehint, debug",
                  in, out,
                  hinting_range_min, hinting_range_max, hinting_limit,
                  gray_strong_stem_width, gdi_cleartype_strong_stem_width,
@@ -719,7 +745,7 @@ main(int argc,
                  pre_hinting, hint_with_components,
                  increase_x_height, x_height_snapping_exceptions_string,
                  latin_fallback, symbol,
-                 debug);
+                 dehint, debug);
 
   if (!no_info)
   {
@@ -797,7 +823,8 @@ main(int argc,
                dw_cleartype_strong_stem_width, increase_x_height,
                x_height_snapping_exceptions_string,
                ignore_restrictions, windows_compatibility, pre_hinting,
-               hint_with_components, no_info, latin_fallback, symbol);
+               hint_with_components, no_info, latin_fallback, symbol,
+               dehint);
   gui.show();
 
   return app.exec();
