@@ -1,6 +1,6 @@
 // maingui.h
 
-// Copyright (C) 2012 by Werner Lemberg.
+// Copyright (C) 2012-2013 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -17,7 +17,8 @@
 #include <config.h>
 
 #include <QtGui>
-#include "lineedit.h"
+#include "ddlineedit.h"
+#include "ttlineedit.h"
 
 #include <stdio.h>
 #include <ttfautohint.h>
@@ -29,13 +30,13 @@ class QCheckBox;
 class QComboBox;
 class QFile;
 class QLabel;
-class QLineEdit;
 class QLocale;
 class QMenu;
 class QPushButton;
 class QSpinBox;
 
-class Line_Edit;
+class Drag_Drop_Line_Edit;
+class Tooltip_Line_Edit;
 
 class Main_GUI
 : public QMainWindow
@@ -47,7 +48,8 @@ public:
            bool, bool, bool,
            int, const char*,
            bool, bool, bool,
-           bool, bool, int, bool);
+           bool, bool, int, bool,
+           bool);
   ~Main_GUI();
 
 protected:
@@ -60,6 +62,7 @@ private slots:
   void check_min();
   void check_max();
   void check_limit();
+  void check_dehint();
   void check_no_limit();
   void check_no_increase();
   void absolute_input();
@@ -86,6 +89,7 @@ private:
   int no_info;
   int latin_fallback;
   int symbol;
+  int dehint;
 
   void create_layout();
 
@@ -104,19 +108,23 @@ private:
   QMenu* file_menu;
   QMenu* help_menu;
 
-  Line_Edit* input_line;
+  Drag_Drop_Line_Edit* input_line;
   QPushButton* input_button;
 
-  Line_Edit* output_line;
+  Drag_Drop_Line_Edit* output_line;
   QPushButton* output_button;
 
+  QLabel* min_label;
   QSpinBox* min_box;
+  QLabel* max_label;
   QSpinBox* max_box;
 
+  QLabel* stem_label;
   QCheckBox* gray_box;
   QCheckBox* gdi_box;
   QCheckBox* dw_box;
 
+  QLabel* fallback_label;
   QComboBox* fallback_box;
 
   QLabel* limit_label;
@@ -127,12 +135,14 @@ private:
   QSpinBox* increase_box;
   QCheckBox* no_increase_box;
 
-  QLineEdit* snapping_line;
+  QLabel* snapping_label;
+  Tooltip_Line_Edit* snapping_line;
 
   QCheckBox* wincomp_box;
   QCheckBox* pre_box;
   QCheckBox* hint_box;
   QCheckBox* symbol_box;
+  QCheckBox* dehint_box;
   QCheckBox* info_box;
 
   QPushButton* run_button;
