@@ -1,7 +1,7 @@
 /* tafpgm.c */
 
 /*
- * Copyright (C) 2011-2012 by Werner Lemberg.
+ * Copyright (C) 2011-2013 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -74,6 +74,7 @@
  *   engine specific corrections are applied.
  *
  * in: val
+ *
  * out: ROUND(val)
  */
 
@@ -150,6 +151,8 @@ unsigned char FPGM(bci_round) [] =
  *
  * CVT: cvtl_is_extra_light
  *      std_width
+ *
+ * uses: bci_round
  */
 
 unsigned char FPGM(bci_smooth_stem_width_a) [] =
@@ -328,10 +331,10 @@ unsigned char FPGM(bci_smooth_stem_width_c) [] =
  * out: n+1
  *      dist
  *
- * CVT: widths[]
- *
  * sal: sal_best
  *      sal_ref
+ *
+ * CVT: widths[]
  */
 
 unsigned char FPGM(bci_get_best_width) [] =
@@ -419,7 +422,13 @@ unsigned char FPGM(bci_get_best_width) [] =
  *
  * out: new_width
  *
+ * sal: sal_best
+ *      sal_ref
+ *
  * CVT: widths[]
+ *
+ * uses: bci_get_best_width
+ *       bci_round
  */
 
 unsigned char FPGM(bci_strong_stem_width_a) [] =
@@ -520,19 +529,57 @@ unsigned char FPGM(bci_strong_stem_width_b) [] =
 };
 
 
+/*
+ * bci_do_loop
+ *
+ *   An auxiliary function for `bci_loop'.
+ *
+ * sal: sal_i (gets incremented by 2 after execution)
+ *      sal_func
+ *
+ * uses: func[sal_func]
+ */
+
+unsigned char FPGM(bci_loop_do) [] =
+{
+
+  PUSHB_1,
+    bci_loop_do,
+  FDEF,
+
+  PUSHB_1,
+    sal_func,
+  RS,
+  CALL,
+
+  PUSHB_3,
+    sal_i,
+    2,
+    sal_i,
+  RS,
+  ADD, /* sal_i = sal_i + 2 */
+  WS,
+
+  ENDF,
+
+};
+
+
 /*
  * bci_loop
  *
- *   Take a range and a function number and apply the function to all
- *   elements of the range.
+ *   Take a range `start'..`end' and a function number and apply the
+ *   associated function to the range elements `start', `start+2',
+ *   `start+4', ...
  *
  * in: func_num
  *     end
  *     start
  *
  * sal: sal_i (counter initialized with `start')
- *      sal_limit (`end')
  *      sal_func (`func_num')
+ *
+ * uses: bci_loop_do
  */
 
 unsigned char FPGM(bci_loop) [] =
@@ -546,41 +593,25 @@ unsigned char FPGM(bci_loop) [] =
     sal_func,
   SWAP,
   WS, /* sal_func = func_num */
-  PUSHB_1,
-    sal_limit,
+
   SWAP,
-  WS, /* sal_limit = end */
+  DUP,
   PUSHB_1,
     sal_i,
   SWAP,
   WS, /* sal_i = start */
 
-/* start_loop: */
+  SUB,
   PUSHB_1,
-    sal_i,
-  RS,
+    2*64,
+  DIV,
   PUSHB_1,
-    sal_limit,
-  RS,
-  LTEQ, /* start <= end */
-  IF,
-    PUSHB_1,
-      sal_func,
-    RS,
-    CALL,
-    PUSHB_3,
-      sal_i,
-      1,
-      sal_i,
-    RS,
-    ADD, /* start = start + 1 */
-    WS,
+    1,
+  ADD, /* number of loops ((end - start) / 2 + 1) */
 
-    PUSHB_1,
-      22,
-    NEG,
-    JMPR, /* goto start_loop */
-  EIF,
+  PUSHB_1,
+    bci_loop_do,
+  LOOPCALL,
 
   ENDF,
 
@@ -596,7 +627,9 @@ unsigned char FPGM(bci_loop) [] =
  *   consequently, the calculation `a * b/c' is done as `a + delta' with
  *   `delta = a * (b-c)/c'.  This avoids overflow.
  *
- * sal: sal_i (CVT index)
+ * in: cvt_idx
+ *
+ * out: cvt_idx+1
  *
  * CVT: cvtl_scale
  *      cvtl_0x10000
@@ -609,14 +642,16 @@ unsigned char FPGM(bci_cvt_rescale) [] =
     bci_cvt_rescale,
   FDEF,
 
-  PUSHB_1,
-    sal_i,
-  RS,
+  DUP,
   DUP,
   RCVT,
   DO_SCALE,
   WCVTP,
 
+  PUSHB_1,
+    1,
+  ADD,
+
   ENDF,
 
 };
@@ -627,8 +662,11 @@ unsigned char FPGM(bci_cvt_rescale) [] =
  *
  *   Round a blue ref value and adjust its corresponding shoot value.
  *
- * sal: sal_i (CVT index)
+ * in: ref_idx
  *
+ * out: ref_idx+1
+ *
+ * uses: bci_round
  */
 
 unsigned char FPGM(bci_blue_round_a) [] =
@@ -638,17 +676,15 @@ unsigned char FPGM(bci_blue_round_a) [] =
     bci_blue_round,
   FDEF,
 
-  PUSHB_1,
-    sal_i,
-  RS,
   DUP,
-  RCVT, /* s: ref_idx ref */
+  DUP,
+  RCVT, /* s: ref_idx ref_idx ref */
 
   DUP,
   PUSHB_1,
     bci_round,
   CALL,
-  SWAP, /* s: ref_idx round(ref) ref */
+  SWAP, /* s: ref_idx ref_idx round(ref) ref */
 
   PUSHB_2,
 
@@ -661,15 +697,15 @@ unsigned char FPGM(bci_blue_round_b) [] =
 
     4,
   CINDEX,
-  ADD, /* s: ref_idx round(ref) ref shoot_idx */
+  ADD, /* s: ref_idx ref_idx round(ref) ref shoot_idx */
   DUP,
-  RCVT, /* s: ref_idx round(ref) ref shoot_idx shoot */
+  RCVT, /* s: ref_idx ref_idx round(ref) ref shoot_idx shoot */
 
-  ROLL, /* s: ref_idx round(ref) shoot_idx shoot ref */
+  ROLL, /* s: ref_idx ref_idx round(ref) shoot_idx shoot ref */
   SWAP,
-  SUB, /* s: ref_idx round(ref) shoot_idx dist */
+  SUB, /* s: ref_idx ref_idx round(ref) shoot_idx dist */
   DUP,
-  ABS, /* s: ref_idx round(ref) shoot_idx dist delta */
+  ABS, /* s: ref_idx ref_idx round(ref) shoot_idx dist delta */
 
   DUP,
   PUSHB_1,
@@ -694,7 +730,7 @@ unsigned char FPGM(bci_blue_round_b) [] =
     EIF,
   EIF,
 
-  SWAP, /* s: ref_idx round(ref) shoot_idx delta dist */
+  SWAP, /* s: ref_idx ref_idx round(ref) shoot_idx delta dist */
   PUSHB_1,
     0,
   LT, /* dist < 0 */
@@ -706,11 +742,15 @@ unsigned char FPGM(bci_blue_round_b) [] =
     3,
   CINDEX,
   SWAP,
-  SUB, /* s: ref_idx round(ref) shoot_idx (round(ref) - delta) */
+  SUB, /* s: ref_idx ref_idx round(ref) shoot_idx (round(ref) - delta) */
 
   WCVTP,
   WCVTP,
 
+  PUSHB_1,
+    1,
+  ADD, /* s: (ref_idx + 1) */
+
   ENDF,
 
 };
@@ -752,6 +792,7 @@ unsigned char FPGM(bci_decrement_component_counter) [] =
  *   An auxiliary function for `bci_create_segment'.
  *
  * in: point-1
+ *
  * out: point
  *
  * sal: sal_point_min
@@ -966,16 +1007,13 @@ unsigned char FPGM(bci_number_set_is_element2) [] =
  *   Store start and end point of a segment in the storage area,
  *   then construct a point in the twilight zone to represent it.
  *
- *   This function is used by `bci_create_segment_points'.
+ *   This function is used by `bci_create_segments'.
  *
  * in: start
  *     end
  *       [last (if wrap-around segment)]
  *       [first (if wrap-around segment)]
  *
- * uses: bci_get_point_extrema
- *       bci_nibbles
- *
  * sal: sal_i (start of current segment)
  *      sal_j (current twilight point)
  *      sal_point_min
@@ -987,6 +1025,9 @@ unsigned char FPGM(bci_number_set_is_element2) [] =
  *      cvtl_0x10000
  *      cvtl_temp
  *
+ * uses: bci_get_point_extrema
+ *       bci_nibbles
+ *
  * If `sal_num_packed_segments' is > 0, the start/end pair is stored as
  * delta values in nibbles (without a wrap-around segment).
  */
@@ -1026,15 +1067,6 @@ unsigned char FPGM(bci_create_segment) [] =
   CINDEX,
   WS, /* sal[sal_i] = start */
 
-  /* increase `sal_i'; together with the outer loop, this makes sal_i += 2 */
-  PUSHB_3,
-    sal_i,
-    1,
-    sal_i,
-  RS,
-  ADD, /* sal_i = sal_i + 1 */
-  WS,
-
   /* initialize inner loop(s) */
   PUSHB_2,
     sal_point_min,
@@ -1065,13 +1097,15 @@ unsigned char FPGM(bci_create_segment) [] =
     /* `start'-`last' and `first'-`end' */
 
     /* s: first last start end */
-    PUSHB_1,
+    PUSHB_2,
+      1,
       sal_i,
     RS,
+    ADD,
     PUSHB_1,
       4,
     CINDEX,
-    WS, /* sal[sal_i] = last */
+    WS, /* sal[sal_i + 1] = last */
 
     ROLL,
     ROLL, /* s: first end last start */
@@ -1102,13 +1136,15 @@ unsigned char FPGM(bci_create_segment) [] =
     POP,
 
   ELSE, /* s: start end */
-    PUSHB_1,
+    PUSHB_2,
+      1,
       sal_i,
     RS,
+    ADD,
     PUSHB_1,
       2,
     CINDEX,
-    WS, /* sal[sal_i] = end */
+    WS, /* sal[sal_i + 1] = end */
 
     PUSHB_1,
       2,
@@ -1194,8 +1230,6 @@ unsigned char FPGM(bci_create_segment) [] =
  *       [contour_first (N-1) (if wrap-around segment)]
  *     ... stuff for bci_hint_glyph ...
  *
- * uses: bci_create_segment
- *
  * sal: sal_i (start of current segment)
  *      sal_j (current twilight point)
  *      sal_num_packed_segments
@@ -1203,6 +1237,10 @@ unsigned char FPGM(bci_create_segment) [] =
  *
  * CVT: cvtl_is_subglyph
  *
+ * uses: bci_create_segment
+ *       bci_loop
+ *       bci_hint_glyph
+ *
  * If `num_packed_segments' is set to p, the first p start/end pairs are
  * stored as delta values in nibbles, with the `start' delta in the lower
  * nibble (and there are no wrap-around segments).  For example, if the
@@ -1253,8 +1291,6 @@ unsigned char FPGM(bci_create_segments) [] =
     ROLL,
     ADD, /* s: ... sal_segment_offset (sal_segment_offset + delta) */
 
-    /* `bci_create_segment_point' also increases the loop counter by 1; */
-    /* this effectively means we have a loop step of 2 */
     PUSHB_2,
       bci_create_segment,
       bci_loop,
@@ -1446,9 +1482,15 @@ unsigned char FPGM(bci_create_segments_9) [] =
  *   The same as `bci_create_segments'.
  *   It also decrements the composite component counter.
  *
- * uses: bci_decrement_composite_counter
+ * sal: sal_num_packed_segments
+ *      sal_segment_offset
  *
  * CVT: cvtl_is_subglyph
+ *
+ * uses: bci_decrement_component_counter
+ *       bci_create_segment
+ *       bci_loop
+ *       bci_hint_glyph
  */
 
 unsigned char FPGM(bci_create_segments_composite) [] =
@@ -1497,8 +1539,6 @@ unsigned char FPGM(bci_create_segments_composite) [] =
     ROLL,
     ADD, /* s: ... sal_segment_offset (sal_segment_offset + delta) */
 
-    /* `bci_create_segment_point' also increases the loop counter by 1; */
-    /* this effectively means we have a loop step of 2 */
     PUSHB_2,
       bci_create_segment,
       bci_loop,
@@ -1684,6 +1724,35 @@ unsigned char FPGM(bci_create_segments_composite_9) [] =
 };
 
 
+/*
+ * bci_align_point
+ *
+ *   An auxiliary function for `bci_align_segment'.
+ *
+ * in: point
+ *
+ * out: point+1
+ */
+
+unsigned char FPGM(bci_align_point) [] =
+{
+
+  PUSHB_1,
+    bci_align_point,
+  FDEF,
+
+  DUP,
+  ALIGNRP, /* align point with rp0 */
+
+  PUSHB_1,
+    1,
+  ADD,
+
+  ENDF,
+
+};
+
+
 /*
  * bci_align_segment
  *
@@ -1691,6 +1760,10 @@ unsigned char FPGM(bci_create_segments_composite_9) [] =
  *   zp0 and zp1 must be set to 0 (twilight) and 1 (normal), respectively.
  *
  * in: segment_index
+ *
+ * sal: sal_segment_offset
+ *
+ * uses: bci_align_point
  */
 
 unsigned char FPGM(bci_align_segment) [] =
@@ -1715,33 +1788,19 @@ unsigned char FPGM(bci_align_segment) [] =
   ADD,
   RS, /* s: first last */
 
-/* start_loop: */
   PUSHB_1,
     2,
   CINDEX, /* s: first last first */
+  SUB,
   PUSHB_1,
-    2,
-  CINDEX, /* s: first last first last */
-  LTEQ, /* first <= end */
-  IF, /* s: first last */
-    SWAP,
-    DUP, /* s: last first first */
-    ALIGNRP, /* align point with index `first' with rp0 */
+    1,
+  ADD, /* s: first loop_count */
 
-    PUSHB_1,
-      1,
-    ADD, /* first = first + 1 */
-    SWAP, /* s: first last */
-
-    PUSHB_1,
-      18,
-    NEG,
-    JMPR, /* goto start_loop */
-
-  ELSE,
-    POP,
-    POP,
-  EIF,
+  PUSHB_1,
+    bci_align_point,
+  LOOPCALL,
+  /* clean up stack */
+  POP,
 
   ENDF,
 
@@ -1761,8 +1820,7 @@ unsigned char FPGM(bci_align_segment) [] =
  *       ...
  *       segment_N
  *
- * uses: handle_segment
- *
+ * uses: bci_align_segment
  */
 
 unsigned char FPGM(bci_align_segments) [] =
@@ -1860,9 +1918,9 @@ unsigned char FPGM(bci_scale_contour) [] =
  *       min_point_N
  *       max_point_N
  *
- * uses: bci_scale_contour
- *
  * CVT: cvtl_is_subglyph
+ *
+ * uses: bci_scale_contour
  */
 
 unsigned char FPGM(bci_scale_glyph) [] =
@@ -1907,12 +1965,13 @@ unsigned char FPGM(bci_scale_glyph) [] =
 /*
  * bci_scale_composite_glyph
  *
- *   The same as `bci_scale_composite_glyph'.
+ *   The same as `bci_scale_glyph'.
  *   It also decrements the composite component counter.
  *
- * uses: bci_decrement_component_counter
- *
  * CVT: cvtl_is_subglyph
+ *
+ * uses: bci_decrement_component_counter
+ *       bci_scale_contour
  */
 
 unsigned char FPGM(bci_scale_composite_glyph) [] =
@@ -1966,8 +2025,9 @@ unsigned char FPGM(bci_scale_composite_glyph) [] =
  *   It expects that rp1 (pointed to by zp0) is set up properly; zp2 must
  *   point to the normal zone 1.
  *
- * in:  contour
- * out: contour + 1
+ * in: contour
+ *
+ * out: contour+1
  */
 
 unsigned char FPGM(bci_shift_contour) [] =
@@ -2020,6 +2080,9 @@ unsigned char FPGM(bci_shift_contour) [] =
  * CVT: cvtl_funits_to_pixels
  *      cvtl_0x10000
  *      cvtl_scale
+ *
+ * uses: bci_round
+ *       bci_shift_contour
  */
 
 unsigned char FPGM(bci_shift_subglyph) [] =
@@ -2488,6 +2551,8 @@ unsigned char FPGM(bci_action_ip_between) [] =
  * bci_adjust_common
  *
  *   Common code for bci_action_adjust routines.
+ *
+ * uses: func[cvtl_stem_width_function]
  */
 
 unsigned char FPGM(bci_adjust_common) [] =
@@ -2544,6 +2609,7 @@ unsigned char FPGM(bci_adjust_common) [] =
  *     ... stuff for bci_align_segments (edge) ...
  *
  * uses: bci_adjust_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_adjust_bound) [] =
@@ -2675,6 +2741,7 @@ unsigned char FPGM(bci_action_adjust_bound_round_serif) [] =
  *     ... stuff for bci_align_segments (edge) ...
  *
  * uses: bci_adjust_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_adjust) [] =
@@ -2783,6 +2850,14 @@ unsigned char FPGM(bci_action_adjust_round_serif) [] =
  * bci_stem_common
  *
  *   Common code for bci_action_stem routines.
+ *
+ * sal: sal_anchor
+ *      sal_temp1
+ *      sal_temp2
+ *      sal_temp3
+ *
+ * uses: func[cvtl_stem_width_function]
+ *       bci_round
  */
 
 #undef sal_u_off
@@ -3079,6 +3154,7 @@ unsigned char FPGM(bci_stem_common) [] =
  *      sal_temp3
  *
  * uses: bci_stem_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_stem_bound) [] =
@@ -3237,6 +3313,7 @@ unsigned char FPGM(bci_action_stem_bound_round_serif) [] =
  *      sal_temp3
  *
  * uses: bci_stem_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_stem) [] =
@@ -3369,6 +3446,9 @@ unsigned char FPGM(bci_action_stem_round_serif) [] =
  *     base_point (in twilight zone)
  *     stem_point (in twilight zone)
  *     ... stuff for bci_align_segments (base) ...
+ *
+ * uses: func[cvtl_stem_width_function]
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_link) [] =
@@ -3538,6 +3618,10 @@ unsigned char FPGM(bci_action_link_round_serif) [] =
  *      sal_temp1
  *      sal_temp2
  *      sal_temp3
+ *
+ * uses: func[cvtl_stem_width_function]
+ *       bci_round
+ *       bci_align_segments
  */
 
 #undef sal_u_off
@@ -3836,6 +3920,8 @@ unsigned char FPGM(bci_action_blue_anchor) [] =
  * in: blue_cvt_idx
  *     edge_point (in twilight zone)
  *     ... stuff for bci_align_segments (edge) ...
+ *
+ * uses: bci_align_segments
  */
 
 unsigned char FPGM(bci_action_blue) [] =
@@ -3916,6 +4002,8 @@ unsigned char FPGM(bci_serif_common) [] =
  *
  * in: edge
  *     bound
+ *
+ * uses: bci_align_segments
  */
 
 unsigned char FPGM(bci_lower_bound) [] =
@@ -3959,6 +4047,8 @@ unsigned char FPGM(bci_lower_bound) [] =
  *
  * in: edge
  *     bound
+ *
+ * uses: bci_align_segments
  */
 
 unsigned char FPGM(bci_upper_bound) [] =
@@ -4003,6 +4093,8 @@ unsigned char FPGM(bci_upper_bound) [] =
  * in: edge
  *     lower
  *     upper
+ *
+ * uses: bci_align_segments
  */
 
 unsigned char FPGM(bci_upper_lower_bound) [] =
@@ -4063,6 +4155,7 @@ unsigned char FPGM(bci_upper_lower_bound) [] =
  *     ... stuff for bci_align_segments (serif) ...
  *
  * uses: bci_serif_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_action_serif) [] =
@@ -4203,6 +4296,10 @@ unsigned char FPGM(bci_action_serif_upper_lower_bound) [] =
  * bci_serif_anchor_common
  *
  *   Common code for bci_action_serif_anchor routines.
+ *
+ * sal: sal_anchor
+ *
+ * uses: bci_round
  */
 
 unsigned char FPGM(bci_serif_anchor_common) [] =
@@ -4250,6 +4347,7 @@ unsigned char FPGM(bci_serif_anchor_common) [] =
  *     ... stuff for bci_align_segments (edge) ...
  *
  * uses: bci_serif_anchor_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_action_serif_anchor) [] =
@@ -4386,6 +4484,8 @@ unsigned char FPGM(bci_action_serif_anchor_upper_lower_bound) [] =
  * bci_serif_link1_common
  *
  *   Common code for bci_action_serif_link1 routines.
+ *
+ * CVT: cvtl_0x10000
  */
 
 unsigned char FPGM(bci_serif_link1_common) [] =
@@ -4501,6 +4601,7 @@ unsigned char FPGM(bci_serif_link1_common) [] =
  *     ... stuff for bci_align_segments (edge) ...
  *
  * uses: bci_serif_link1_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_action_serif_link1) [] =
@@ -4643,6 +4744,8 @@ unsigned char FPGM(bci_action_serif_link1_upper_lower_bound) [] =
  * bci_serif_link2_common
  *
  *   Common code for bci_action_serif_link2 routines.
+ *
+ * sal: sal_anchor
  */
 
 unsigned char FPGM(bci_serif_link2_common) [] =
@@ -4695,6 +4798,7 @@ unsigned char FPGM(bci_serif_link2_common) [] =
  *     ... stuff for bci_align_segments (edge) ...
  *
  * uses: bci_serif_link2_common
+ *       bci_align_segments
  */
 
 unsigned char FPGM(bci_action_serif_link2) [] =
@@ -4839,6 +4943,8 @@ unsigned char FPGM(bci_action_serif_link2_upper_lower_bound) [] =
  *       ... data ...
  *     ...
  *
+ * CVT: cvtl_is_subglyph
+ *
  * uses: bci_action_ip_before
  *       bci_action_ip_after
  *       bci_action_ip_on
@@ -4897,8 +5003,6 @@ unsigned char FPGM(bci_action_serif_link2_upper_lower_bound) [] =
  *       bci_action_serif_link2_lower_bound
  *       bci_action_serif_link2_upper_bound
  *       bci_action_serif_link2_upper_lower_bound
- *
- * CVT: cvtl_is_subglyph
  */
 
 unsigned char FPGM(bci_hint_glyph) [] =
@@ -4962,6 +5066,7 @@ TA_table_build_fpgm(FT_Byte** fpgm,
             + sizeof (FPGM(bci_strong_stem_width_a))
             + 2
             + sizeof (FPGM(bci_strong_stem_width_b))
+            + sizeof (FPGM(bci_loop_do))
             + sizeof (FPGM(bci_loop))
             + sizeof (FPGM(bci_cvt_rescale))
             + sizeof (FPGM(bci_blue_round_a))
@@ -5000,6 +5105,7 @@ TA_table_build_fpgm(FT_Byte** fpgm,
             + sizeof (FPGM(bci_create_segments_composite_8))
             + sizeof (FPGM(bci_create_segments_composite_9))
 
+            + sizeof (FPGM(bci_align_point))
             + sizeof (FPGM(bci_align_segment))
             + sizeof (FPGM(bci_align_segments))
 
@@ -5115,6 +5221,7 @@ TA_table_build_fpgm(FT_Byte** fpgm,
   *(buf_p++) = (unsigned char)CVT_VERT_WIDTHS_OFFSET(font);
   *(buf_p++) = (unsigned char)CVT_VERT_WIDTHS_SIZE(font);
   COPY_FPGM(bci_strong_stem_width_b);
+  COPY_FPGM(bci_loop_do);
   COPY_FPGM(bci_loop);
   COPY_FPGM(bci_cvt_rescale);
   COPY_FPGM(bci_blue_round_a);
@@ -5153,6 +5260,7 @@ TA_table_build_fpgm(FT_Byte** fpgm,
   COPY_FPGM(bci_create_segments_composite_8);
   COPY_FPGM(bci_create_segments_composite_9);
 
+  COPY_FPGM(bci_align_point);
   COPY_FPGM(bci_align_segment);
   COPY_FPGM(bci_align_segments);
 
